Module devotee::visual

source ·
Set of visualization primitives.

Modules

  • Image with dimensions unknown at compile-time.
  • Color system used in devotee.
  • Collection of drawing traits and functions compiles in a single prelude.
  • Image with compile-time known dimensions.

Structs

  • Painter to draw on encapsulated target.

Traits

Functions

  • Helper draw function for pixel value combining. It mixes original pixel value and provided value.
  • Helper mixer mapper for image-to-image mapping. It just mixes original pixels and pixels of stamped image.
  • Helper paint function for pixel value override. It ignores the value of original pixel and replaces it with value.
  • Helper printer mapper for the Text trait. It breaks lines on newline symbol ('\n') and ignores any special characters.
  • Helper stamper mapper for image-to-image mapping. It stamps pixels of the drawn image ignoring values of the original.

Type Definitions

  • Mapper function accepts x and y coordinates and pixel value.